@@ -640,6 +640,12 @@ IMM_ResetInput (IMM_CLIENT * p)
   return 1;
 }
 
+int
+IMM_Flush(IMM_CLIENT *p)
+{
+  return 1;
+}
+
 #ifdef  __cplusplus
 extern "C"
 #endif
@@ -663,7 +669,7 @@ struct ImmOperation ImmOp_Ptr = {
   NULL,				//IMM_pGetItem,
   NULL,				//IMM_AddPhrase,
   NULL,				//IMM_ModifyPhraseItem,
-  NULL,				//IMM_Flush,
+  IMM_Flush,			//IMM_Flush,
 };
 
 //Test part
