@@ -801,8 +801,12 @@ int TL_GetSelectDisplay (HzInputTable_T * p, char *buf)
 {
     int i, len;  
     char buf1[256];
+    char mb_space[MB_CUR_MAX];
     
     buf[0] = '\0';
+
+    wctomb(mb_space, 0x3000);
+
     if (p->CurSelNum == 0)
          return 0;
     /* not first page */
@@ -810,10 +814,10 @@ int TL_GetSelectDisplay (HzInputTable_T * p, char *buf)
         strcat (buf, "< ");
     for (i = 0; i < p->CurSelNum; i++)
     {
-        if (i != 9)
-            sprintf (buf1, "%d%s ", i + 1, p->seltab[i]);
+        if (mbstowcs(NULL, p->seltab[i], 0) > 0)
+            sprintf (buf1, "%d%s ", (i + 1) % 10, p->seltab[i]);
         else
-            sprintf (buf1, "0%s ", p->seltab[i]);
+            sprintf (buf1, "%d%s ", (i + 1) % 10, mb_space);
         len = strlen(buf1);
         strcat (buf, buf1);
     }
